# Version 0.1.18

This release includes important bug fixes to improve the user experience and reliability of health checks for deployed applications.

## New Features

- No new features were added in this release.

## Bug Fixes

- Prevent the node from jumping when resizing after resetting to the default size (09a1b2) (Eric Ma)
- Update health check to ping the actual deployed app URLs using the /health endpoint, accept only HTTP 200 responses, increase retry delay for cold starts, and improve deployment summaries and PR comments (baaee4) (Eric Ma)

## Deprecations

- No deprecations in this release.
